# Generated by Django 4.2.21 on 2026-02-27 23:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0119_bigbrotherconfig_main_alliance_defaults'),
    ]

    operations = [
        migrations.RenameIndex(
            model_name='alliancehistorycache',
            new_name='aa_bb_allia_updated_732c6f_idx',
            old_name='alliance_hi_updated_df5e96_idx',
        ),
        migrations.RenameIndex(
            model_name='awoxkillscache',
            new_name='aa_bb_awoxk_updated_821fca_idx',
            old_name='awox_kills__updated_d44021_idx',
        ),
        migrations.RenameIndex(
            model_name='awoxkillscache',
            new_name='aa_bb_awoxk_last_ac_b03b46_idx',
            old_name='awox_kills__last_ac_0e466a_idx',
        ),
        migrations.RenameIndex(
            model_name='characteremploymentcache',
            new_name='aa_bb_chara_updated_588126_idx',
            old_name='character_e_updated_40b6bb_idx',
        ),
        migrations.RenameIndex(
            model_name='characteremploymentcache',
            new_name='aa_bb_chara_last_ac_40e75b_idx',
            old_name='character_e_last_ac_44a363_idx',
        ),
        migrations.RenameIndex(
            model_name='corporationinfocache',
            new_name='aa_bb_corpo_updated_baa230_idx',
            old_name='corporation_updated_0654f8_idx',
        ),
        migrations.RenameIndex(
            model_name='currentstintcache',
            new_name='aa_bb_curre_char_id_e11ac5_idx',
            old_name='current_sti_char_id_0bbf63_idx',
        ),
        migrations.RenameIndex(
            model_name='currentstintcache',
            new_name='aa_bb_curre_updated_f71c0e_idx',
            old_name='current_sti_updated_28b144_idx',
        ),
        migrations.RenameIndex(
            model_name='currentstintcache',
            new_name='aa_bb_curre_last_ac_1c7d4d_idx',
            old_name='current_sti_last_ac_f56fae_idx',
        ),
        migrations.RenameIndex(
            model_name='frequentcorpchangescache',
            new_name='aa_bb_frequ_updated_a0457c_idx',
            old_name='frequent_co_updated_43ba09_idx',
        ),
        migrations.RenameIndex(
            model_name='frequentcorpchangescache',
            new_name='aa_bb_frequ_last_ac_ca06e7_idx',
            old_name='frequent_co_last_ac_bfcec4_idx',
        ),
    ]
