# Generated by Django 4.2.23 on 2026-02-27 00:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aa_bb", "0118_tickettoolconfig_compliance_filter_state"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bigbrotherconfig",
            name="main_alliance_id",
            field=models.PositiveIntegerField(
                default=0,
                editable=False,
                help_text="Your Alliance ID",
                verbose_name="Main Alliance ID",
            ),
        ),
        migrations.AlterField(
            model_name="bigbrotherconfig",
            name="main_alliance",
            field=models.TextField(
                default="",
                editable=False,
                help_text="Your Alliance",
                verbose_name="Main Alliance",
            ),
        ),
    ]
