# Generated by Django 4.2.21 on 2026-01-13 15:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0109_alter_tickettoolconfig_discord_check_reason_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='hide_unaudited_users',
            field=models.BooleanField(default=False, help_text='If enabled, users who have no audited characters will be hidden from the main dashboard dropdown.', verbose_name='Hide Unaudited Users'),
        ),
    ]
