# Generated by Django 4.2.23 on 2026-02-26 00:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("aa_bb", "0115_adminlogentry_and_permissions"),
    ]

    operations = [
        migrations.AlterModelTable(name="Alliance_names", table=None),
        migrations.AlterModelTable(name="Corporation_names", table=None),
        migrations.AlterModelTable(name="Character_names", table=None),
        migrations.AlterModelTable(name="id_types", table=None),
        migrations.AlterModelTable(name="ProcessedMail", table=None),
        migrations.AlterModelTable(name="SusMailNote", table=None),
        migrations.AlterModelTable(name="ProcessedContract", table=None),
        migrations.AlterModelTable(name="SusContractNote", table=None),
        migrations.AlterModelTable(name="ProcessedTransaction", table=None),
        migrations.AlterModelTable(name="SusTransactionNote", table=None),
        migrations.AlterModelTable(name="CharacterEmploymentCache", table=None),
        migrations.AlterModelTable(name="FrequentCorpChangesCache", table=None),
        migrations.AlterModelTable(name="CurrentStintCache", table=None),
        migrations.AlterModelTable(name="AwoxKillsCache", table=None),
        migrations.AlterModelTable(name="CorporationInfoCache", table=None),
        migrations.AlterModelTable(name="AllianceHistoryCache", table=None),
        migrations.AlterModelTable(name="SovereigntyMapCache", table=None),
    ]
